@@ -1,5 +1,5 @@
 """
- * $Id: 1.1+16 utils.py f53fd7143efa 2022-02-17 od $
+ * $Id: 1.1+17 utils.py 90c94a5c6c17 2022-03-21 od $
  *
  * This file is part of the Cloud Services Integration Platform (CSIP),
  * a Model-as-a-Service framework, API and application suite.
@@ -11,6 +11,7 @@
 """
 
 import fnmatch
+from contextlib import redirect_stderr
 from os import path
 from pathlib import Path
 from shutil import make_archive
@@ -176,7 +177,9 @@ class Client(object):
                 # response_json = response.json()
                 break
             except requests.exceptions.HTTPError as errh:
-                http_status = response.status_code
+                http_status = -4
+                if response is not None:
+                    http_status = response.status_code
                 # print("Http Error:", errh)
                 # print(response.status_code)
                 break
@@ -216,6 +219,7 @@ class Client(object):
 
         http_status = 200
         response_json = None
+        response = None
         while retry > 0:
             try:
                 response = requests.post(url, files=files, allow_redirects=allow_redirects, headers=headers,
@@ -224,7 +228,9 @@ class Client(object):
                 response_json = response.json()
                 break
             except requests.exceptions.HTTPError as errh:
-                http_status = response.status_code
+                http_status = -4
+                if response is not None:
+                    http_status = response.status_code
                 # print("Http Error:", errh)
                 # print(response.status_code)
                 break
